@@ -1,14 +1,14 @@
 `quasiFsim.fnc` <-
 function(dat) {
   if ("RT" %in% colnames(dat)) {
-     dat.lm = lm(RT ~ SOA + Item + Subject + SOA:Subject + Item:Subject, 
+     dat.lm = stats::lm(RT ~ SOA + Item + Subject + SOA:Subject + Item:Subject, 
 	            data = dat)
   } else {
-     dat.lm = lm(RTsim ~ SOA + Item + Subject + SOA:Subject + Item:Subject, 
+     dat.lm = stats::lm(RTsim ~ SOA + Item + Subject + SOA:Subject + Item:Subject, 
 	            data = dat)
   }
 
-  x = anova(dat.lm)
+  x = stats::anova(dat.lm)
   qF = quasiF.fnc(x["SOA","Mean Sq"], x["Item:Subject", "Mean Sq"],
          x["SOA:Subject", "Mean Sq"], x["Item", "Mean Sq"],
          x["SOA","Df"], x["Item:Subject", "Df"],
